import json

from consul import Consul

from skd_env.dot_env import DotEnv


class ConsulLoader:
    def __init__(self, host='127.0.0.1', port=8500, token=None, scheme='http', consistency='default', dc=None,
                 verify=True):
        self.consul = Consul(host=host, port=port, token=token, scheme=scheme, consistency=consistency,
                             dc=dc, verify=verify)

    def load_from_json(self, file_name):
       with open(file_name) as f:
           json_data = json.load(f)
           for k, v in json_data.items():
               self.consul.kv.put(k, self.to_consul_format(v))

    def load_from_dot_env(self, file_name=None):
        env = DotEnv()
        env.read_env(env_file=file_name)
        for k, v in env.environ.items():
            self.consul.kv.put(k, self.to_consul_format(v))

    @staticmethod
    def to_consul_format(value):
        assert not isinstance(value, dict), 'dict is not supported'
        if isinstance(value, list) or isinstance(value, tuple):
            result = ''
            for item in value:
                result += str(item) + ','
            return result[:-1]
        return str(value)

if __name__ == "__main__":
    ConsulLoader().load_from_json('data.json')
    ConsulLoader().load_from_dot_env()